@@ -33,16 +33,11 @@ import adafruit_lsm6ds.lsm6ds33
 import neopixel
 from adafruit_pybadger.pybadger_base import PyBadgerBase, KeyStates
 
-__version__ = "3.7.6"
+__version__ = "3.7.10"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_PyBadger.git"
 
 Buttons = namedtuple("Buttons", "a b")
 
-try:
-    from typing import Type
-except ImportError:
-    pass
-
 
 class Clue(PyBadgerBase):
     """Class that represents a single CLUE."""
@@ -69,7 +64,7 @@ class Clue(PyBadgerBase):
         self._buttons = KeyStates(self._keys)
 
     @property
-    def button(self) -> Type[tuple]:
+    def button(self) -> Buttons:
         """The buttons on the board.
 
         Example use:
