@@ -40,12 +40,8 @@ import adafruit_lis3dh
 import neopixel
 from adafruit_pybadger.pybadger_base import PyBadgerBase, KeyStates
 
-try:
-    from typing import Type
-except ImportError:
-    pass
 
-__version__ = "3.7.6"
+__version__ = "3.7.10"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_PyBadger.git"
 
 Buttons = namedtuple("Buttons", "b a start select right down up left")
@@ -105,7 +101,7 @@ class PyBadge(PyBadgerBase):
         self._light_sensor = analogio.AnalogIn(board.A7)
 
     @property
-    def button(self) -> Type[tuple]:
+    def button(self) -> Buttons:
         """The buttons on the board.
 
         Example use:
